@@ -38,7 +38,7 @@ class MPVError(Exception):
 class WindowsSocket(threading.Thread):
     """
     Wraps a Windows named pipe in a high-level interface. (Internal)
-    
+
     Data is automatically encoded and decoded as JSON. The callback
     function will be called for each inbound message.
     """
@@ -52,7 +52,7 @@ class WindowsSocket(threading.Thread):
         ipc_socket = "\\\\.\\pipe\\" + ipc_socket
         self.callback = callback
         self.quit_callback = quit_callback
-        
+
         access = _winapi.GENERIC_READ | _winapi.GENERIC_WRITE
         limit = 5 # Connection may fail at first. Try 5 times.
         for _ in range(limit):
@@ -123,7 +123,7 @@ class WindowsSocket(threading.Thread):
 class UnixSocket(threading.Thread):
     """
     Wraps a Unix/Linux socket in a high-level interface. (Internal)
-    
+
     Data is automatically encoded and decoded as JSON. The callback
     function will be called for each inbound message.
     """
@@ -206,7 +206,7 @@ class MPVProcess:
                 mpv_location = "mpv.exe"
             else:
                 mpv_location = "mpv"
-        
+
         log.debug("Staring MPV from {0}.".format(mpv_location))
         ipc_socket_name = ipc_socket
         if os.name == 'nt':
@@ -248,7 +248,7 @@ class MPVProcess:
         else:
             self.process.terminate()
             raise MPVError("MPV start timed out.")
-        
+
         if not ipc_exists or self.process.returncode is not None:
             self.process.terminate()
             raise MPVError("MPV not started.")
@@ -290,7 +290,7 @@ class MPVInter:
         self.quit_callback = quit_callback
         if self.callback is None:
             self.callback = lambda event, data: None
-        
+
         self.socket = Socket(ipc_socket, self.event_callback, self.quit_callback)
         self.socket.start()
         self.command_id = 1
@@ -298,7 +298,7 @@ class MPVInter:
         self.socket_lock = threading.Lock()
         self.cid_result = {}
         self.cid_wait = {}
-    
+
     def stop(self, join=True):
         """Terminate the underlying connection."""
         self.socket.stop(join)
@@ -310,11 +310,11 @@ class MPVInter:
             self.cid_wait[data["request_id"]].set()
         elif "event" in data:
             self.callback(data["event"], data)
-    
+
     def command(self, command, *args):
         """
         Issue a command to MPV. Will block until completed or timeout is reached.
-        
+
         *command* is the name of the MPV command
 
         All further arguments are forwarded to the MPV command.
@@ -356,13 +356,13 @@ class EventHandler(threading.Thread):
         """Create an instance of the thread."""
         self.queue = queue.Queue()
         threading.Thread.__init__(self)
-    
+
     def put_task(self, func, *args):
         """
         Put a new task to the thread.
-        
+
         *func* is the function to call
-        
+
         All further arguments are forwarded to *func*.
         """
         self.queue.put((func, args))
@@ -386,15 +386,15 @@ class EventHandler(threading.Thread):
 class MPV:
     """
     The main MPV interface class. Use this to control MPV.
-    
+
     This will expose all mpv commands as callable methods and all properties.
     You can set properties and call the commands directly.
-    
+
     Please note that if you are using a really old MPV version, a fallback command
     list is used. Not all commands may actually work when this fallback is used.
     """
     def __init__(self, start_mpv=True, ipc_socket=None, mpv_location=None,
-                 log_handler=None, loglevel=None, quit_callback=None, **kwargs):
+                 log_handler=None, loglevel=None, quit_callback=None, start_retries=5, start_retry_delay_ms=1000, **kwargs):
         """
         Create the interface to MPV and process instance.
 
@@ -424,13 +424,14 @@ class MPV:
                 ipc_socket = "/tmp/{0}".format(rand_file)
 
         if start_mpv:
-            # Attempt to start MPV 3 times.
-            for i in range(3):
+            # Attempt to start MPV multiple times.
+            for i in range(start_retries):
                 try:
                     self.mpv_process = MPVProcess(ipc_socket, mpv_location, **kwargs)
                     break
                 except MPVError:
                     log.warning("MPV start failed.", exc_info=1)
+                    time.sleep(start_retry_delay_ms / 1000)
                     continue
             else:
                 raise MPVError("MPV process retry limit reached.")
@@ -455,7 +456,7 @@ class MPV:
         self.observer_lock = threading.Lock()
         self.keybind_id = 1
         self.keybind_lock = threading.Lock()
-        
+
         if log_handler is not None and loglevel is not None:
             self.command("request_log_messages", loglevel)
             @self.on_event("log-message")
@@ -582,7 +583,7 @@ class MPV:
             self.bind_property_observer(name, func)
             return func
         return wrapper
-    
+
     def wait_for_property(self, name):
         """
         Waits for the value of a property to change.
@@ -630,11 +631,11 @@ class MPV:
         """
         Send a command to MPV. All commands are bound to the class by default,
         except JSON IPC specific commands. This may also be useful to retain
-        compatibility with python-mpv, as it does not bind all of the commands. 
+        compatibility with python-mpv, as it does not bind all of the commands.
 
         *command* is the command name.
 
-        All further arguments are forwarded to the MPV command. 
+        All further arguments are forwarded to the MPV command.
         """
         return self.mpv_inter.command(command, *args)
 
